@@ -22,7 +22,9 @@ This file all the availible known caches, maps, and sources for the
 nss_cache package.
 """
 
-__author__ = ('jaq@google.com (Jamie Wilkinson)',
-              'vasilios@google.com (Vasilios Hoffman)')
+__author__ = (
+    "jaq@google.com (Jamie Wilkinson)",
+    "vasilios@google.com (Vasilios Hoffman)",
+)
 
-__version__ = '0.42'
+__version__ = "0.48"
