@@ -13,8 +13,10 @@
 # Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 """Command objects."""
 
-__author__ = ('jaq@google.com (Jamie Wilkinson)',
-              'vasilios@google.com (Vasilios Hoffman)')
+__author__ = (
+    "jaq@google.com (Jamie Wilkinson)",
+    "vasilios@google.com (Vasilios Hoffman)",
+)
 
 import inspect
 from io import StringIO
@@ -50,6 +52,7 @@ class Command(object):
     summary, then a complete description of the command.  This is used
     as part of the help system.
     """
+
     # Well known exit codes.  We reserve anything 30 and under for the
     # number of failed NSS maps (~15 defined under modern linux/glibc
     # implementations of named services.  add fudge facter of 2 until I
@@ -63,7 +66,7 @@ class Command(object):
         # Setup logging.
         self.log = logging.getLogger(__name__)
         if self.__doc__ == Command.__doc__:
-            self.log.warning('No help message set for %r', self)
+            self.log.warning("No help message set for %r", self)
         # Setup command parser.
         self.parser = self._GetParser()
         # Attribute used to hold optional lock object.
@@ -89,13 +92,14 @@ class Command(object):
         parser.disable_interspersed_args()
 
         # commonly used options
-        parser.add_option('-m',
-                          '--map',
-                          action='append',
-                          type='string',
-                          dest='maps',
-                          help='map to operate on, can be'
-                          ' supplied multiple times')
+        parser.add_option(
+            "-m",
+            "--map",
+            action="append",
+            type="string",
+            dest="maps",
+            help="map to operate on, can be" " supplied multiple times",
+        )
 
         return parser
 
@@ -113,8 +117,9 @@ class Command(object):
           0 if the command was successful
           non-zero shell error code if not.
         """
-        raise NotImplementedError('command %r not implemented' %
-                                  self.__class__.__name__)
+        raise NotImplementedError(
+            "command %r not implemented" % self.__class__.__name__
+        )
 
     def _Lock(self, path=None, force=False):
         """Grab a system-wide lock for this command.
@@ -149,17 +154,17 @@ class Command(object):
         """Return the help message for this command."""
         if self.__doc__ is Command.__doc__:
             return None
-        help_text = inspect.getdoc(self) + '\n'
+        help_text = inspect.getdoc(self) + "\n"
         if short:
             # only use the short summary first line
-            help_text = help_text.split('\n')[0]
+            help_text = help_text.split("\n")[0]
         else:
             # lose the short summary first line
-            help_text = '\n'.join(help_text.split('\n')[2:])
+            help_text = "\n".join(help_text.split("\n")[2:])
             help_buffer = StringIO()
             self.parser.print_help(file=help_buffer)
             # lose the first line, which is the usage line
-            help_text += '\n'.join(help_buffer.getvalue().split('\n')[1:])
+            help_text += "\n".join(help_buffer.getvalue().split("\n")[1:])
         return help_text
 
 
@@ -173,35 +178,40 @@ class Update(Command):
     def __init__(self):
         """Initialize the argument parser for this command object."""
         super(Update, self).__init__()
-        self.parser.add_option('-f',
-                               '--full',
-                               action='store_false',
-                               help='force a full update from the data source',
-                               dest='incremental',
-                               default=True)
-        self.parser.add_option('-s',
-                               '--sleep',
-                               action='store',
-                               type='int',
-                               default=False,
-                               dest='delay',
-                               help='number of seconds to sleep before'
-                               ' executing command')
         self.parser.add_option(
-            '--force-write',
-            action='store_true',
-            default=False,
-            dest='force_write',
-            help='force the update to write new maps, overriding'
-            ' safety checks, such as refusing to write empty'
-            'maps.')
+            "-f",
+            "--full",
+            action="store_false",
+            help="force a full update from the data source",
+            dest="incremental",
+            default=True,
+        )
         self.parser.add_option(
-            '--force-lock',
-            action='store_true',
+            "-s",
+            "--sleep",
+            action="store",
+            type="int",
             default=False,
-            dest='force_lock',
-            help='forcibly acquire the lock, and issue a SIGTERM'
-            'to any nsscache process holding the lock.')
+            dest="delay",
+            help="number of seconds to sleep before" " executing command",
+        )
+        self.parser.add_option(
+            "--force-write",
+            action="store_true",
+            default=False,
+            dest="force_write",
+            help="force the update to write new maps, overriding"
+            " safety checks, such as refusing to write empty"
+            "maps.",
+        )
+        self.parser.add_option(
+            "--force-lock",
+            action="store_true",
+            default=False,
+            dest="force_lock",
+            help="forcibly acquire the lock, and issue a SIGTERM"
+            "to any nsscache process holding the lock.",
+        )
 
     def Run(self, conf, args):
         """Run the Update command.
@@ -221,28 +231,26 @@ class Update(Command):
             return e.code
 
         if options.maps:
-            self.log.info('Setting configured maps to %s', options.maps)
+            self.log.info("Setting configured maps to %s", options.maps)
             conf.maps = options.maps
 
         if not options.incremental:
-            self.log.debug('performing FULL update of caches')
+            self.log.debug("performing FULL update of caches")
         else:
-            self.log.debug('performing INCREMENTAL update of caches')
+            self.log.debug("performing INCREMENTAL update of caches")
 
         if options.delay:
-            self.log.info('Delaying %d seconds before executing', options.delay)
+            self.log.info("Delaying %d seconds before executing", options.delay)
             time.sleep(options.delay)
 
-        return self.UpdateMaps(conf,
-                               incremental=options.incremental,
-                               force_write=options.force_write,
-                               force_lock=options.force_lock)
+        return self.UpdateMaps(
+            conf,
+            incremental=options.incremental,
+            force_write=options.force_write,
+            force_lock=options.force_lock,
+        )
 
-    def UpdateMaps(self,
-                   conf,
-                   incremental,
-                   force_write=False,
-                   force_lock=False):
+    def UpdateMaps(self, conf, incremental, force_write=False, force_lock=False):
         """Update each configured map.
 
         For each configured map, create a source and cache object and
@@ -259,20 +267,19 @@ class Update(Command):
         """
         # Grab a lock before we continue!
         if not self._Lock(path=conf.lockfile, force=force_lock):
-            self.log.error('Failed to acquire lock, aborting!')
+            self.log.error("Failed to acquire lock, aborting!")
             return self.ERR_LOCK
 
         retval = 0
         for map_name in conf.maps:
             if map_name not in conf.options:
-                self.log.error('No such map name defined in config: %s',
-                               map_name)
+                self.log.error("No such map name defined in config: %s", map_name)
                 return 1
 
             if incremental:
-                self.log.info('Updating and verifying %s cache.', map_name)
+                self.log.info("Updating and verifying %s cache.", map_name)
             else:
-                self.log.info('Rebuilding and verifying %s cache.', map_name)
+                self.log.info("Rebuilding and verifying %s cache.", map_name)
 
             cache_options = conf.options[map_name].cache
             source_options = conf.options[map_name].source
@@ -291,10 +298,11 @@ class Update(Command):
             # startup directory, but we convewrt them to absolute paths so that future
             # temp dirs do not mess with our output routines.
             old_cwd = os.getcwd()
-            tempdir = tempfile.mkdtemp(dir=cache_options['dir'],
-                                       prefix='nsscache-%s-' % map_name)
-            if not os.path.isabs(cache_options['dir']):
-                cache_options['dir'] = os.path.abspath(cache_options['dir'])
+            tempdir = tempfile.mkdtemp(
+                dir=cache_options["dir"], prefix="nsscache-%s-" % map_name
+            )
+            if not os.path.isabs(cache_options["dir"]):
+                cache_options["dir"] = os.path.abspath(cache_options["dir"])
             if not os.path.isabs(conf.timestamp_dir):
                 conf.timestamp_dir = os.path.abspath(conf.timestamp_dir)
             if not os.path.isabs(tempdir):
@@ -306,30 +314,29 @@ class Update(Command):
                 try:
                     source = source_factory.Create(source_options)
 
-                    updater = self._Updater(map_name, source, cache_options,
-                                            conf)
+                    updater = self._Updater(map_name, source, cache_options, conf)
 
                     if incremental:
-                        self.log.info('Updating and verifying %s cache.',
-                                      map_name)
+                        self.log.info("Updating and verifying %s cache.", map_name)
                     else:
-                        self.log.info('Rebuilding and verifying %s cache.',
-                                      map_name)
+                        self.log.info("Rebuilding and verifying %s cache.", map_name)
 
-                    retval = updater.UpdateFromSource(source,
-                                                      incremental=incremental,
-                                                      force_write=force_write)
+                    retval = updater.UpdateFromSource(
+                        source, incremental=incremental, force_write=force_write
+                    )
                 except error.PermissionDenied:
                     self.log.error(
-                        'Permission denied: could not update map %r.  Aborting',
-                        map_name)
+                        "Permission denied: could not update map %r.  Aborting",
+                        map_name,
+                    )
                     retval += 1
                 except (error.EmptyMap, error.InvalidMap) as e:
                     self.log.error(e)
                     retval += 1
                 except error.InvalidMerge as e:
-                    self.log.warning('Could not merge map %r: %s.  Skipping.',
-                                     map_name, e)
+                    self.log.warning(
+                        "Could not merge map %r: %s.  Skipping.", map_name, e
+                    )
             finally:
                 # Start chdir cleanup
                 os.chdir(old_cwd)
@@ -343,25 +350,24 @@ class Update(Command):
         # to determine which type of updater the source uses. At the moment
         # there's only two, so not a huge deal. If we add another we should
         # refactor though.
-        if hasattr(source, 'UPDATER') and source.UPDATER == config.UPDATER_FILE:
+        if hasattr(source, "UPDATER") and source.UPDATER == config.UPDATER_FILE:
             if map_name == config.MAP_AUTOMOUNT:
                 return files_updater.FileAutomountUpdater(
-                    map_name, conf.timestamp_dir, cache_options)
+                    map_name, conf.timestamp_dir, cache_options
+                )
             else:
-                return files_updater.FileMapUpdater(map_name,
-                                                    conf.timestamp_dir,
-                                                    cache_options,
-                                                    can_do_incremental=True)
+                return files_updater.FileMapUpdater(
+                    map_name, conf.timestamp_dir, cache_options, can_do_incremental=True
+                )
         else:
             if map_name == config.MAP_AUTOMOUNT:
-                return map_updater.AutomountUpdater(map_name,
-                                                    conf.timestamp_dir,
-                                                    cache_options)
+                return map_updater.AutomountUpdater(
+                    map_name, conf.timestamp_dir, cache_options
+                )
             else:
-                return map_updater.MapUpdater(map_name,
-                                              conf.timestamp_dir,
-                                              cache_options,
-                                              can_do_incremental=True)
+                return map_updater.MapUpdater(
+                    map_name, conf.timestamp_dir, cache_options, can_do_incremental=True
+                )
 
 
 class Verify(Command):
@@ -389,27 +395,26 @@ class Verify(Command):
             return e.code
 
         if options.maps:
-            self.log.info('Setting configured maps to %s', options.maps)
+            self.log.info("Setting configured maps to %s", options.maps)
             conf.maps = options.maps
 
         (warnings, errors) = (0, 0)
-        self.log.info('Verifying program and system configuration.')
+        self.log.info("Verifying program and system configuration.")
         (config_warnings, config_errors) = config.VerifyConfiguration(conf)
         warnings += config_warnings
         errors += config_errors
 
-        self.log.info('Verifying data sources.')
+        self.log.info("Verifying data sources.")
         errors += self.VerifySources(conf)
 
-        self.log.info('Verifying data caches.')
+        self.log.info("Verifying data caches.")
         errors += self.VerifyMaps(conf)
 
-        self.log.info('Verification result: %d warnings, %d errors', warnings,
-                      errors)
+        self.log.info("Verification result: %d warnings, %d errors", warnings, errors)
         if warnings + errors:
-            self.log.info('Verification failed!')
+            self.log.info("Verification failed!")
         else:
-            self.log.info('Verification passed!')
+            self.log.info("Verification passed!")
 
         return warnings + errors
 
@@ -434,33 +439,33 @@ class Verify(Command):
         retval = 0
 
         for map_name in conf.maps:
-            self.log.info('Verifying map: %s.', map_name)
+            self.log.info("Verifying map: %s.", map_name)
 
             # The netgroup map does not have an enumerator,
             # to test this we'd have to loop over the loaded cache map
             # and verify each entry is retrievable via getent directly.
             # TODO(blaed): apply fix from comment to allow for netgroup checking
             if map_name == config.MAP_NETGROUP:
-                self.log.info(('The netgroup map does not support enumeration, '
-                               'skipping.'))
+                self.log.info(
+                    ("The netgroup map does not support enumeration, " "skipping.")
+                )
                 continue
 
             # Automount maps do not support getent, we'll have to come up with
             # a good way to verify these.
             if map_name == config.MAP_AUTOMOUNT:
                 self.log.info(
-                    ('The automount map does not support enumeration, '
-                     'skipping.'))
+                    ("The automount map does not support enumeration, " "skipping.")
+                )
                 continue
 
             try:
                 nss_map = nss.GetMap(map_name)
             except error.UnsupportedMap:
-                self.log.warning('Verification of %s map is unsupported!',
-                                 map_name)
+                self.log.warning("Verification of %s map is unsupported!", map_name)
                 continue
 
-            self.log.debug('built NSS map of %d entries', len(nss_map))
+            self.log.debug("built NSS map of %d entries", len(nss_map))
 
             cache_options = conf.options[map_name].cache
             cache = cache_factory.Create(cache_options, map_name)
@@ -468,11 +473,11 @@ class Verify(Command):
             try:
                 cache_map = cache.GetMap()
             except error.CacheNotFound:
-                self.log.error('Cache missing!')
+                self.log.error("Cache missing!")
                 retval += 1
                 continue
 
-            self.log.debug('built cache map of %d entries', len(cache_map))
+            self.log.debug("built cache map of %d entries", len(cache_map))
 
             # cache_map is a subset of nss_map due to possible other maps,
             # e.g. files, nis, ldap, etc.
@@ -480,14 +485,17 @@ class Verify(Command):
             for map_entry in cache_map:
                 if map_entry not in nss_map:
                     self.log.info(
-                        'The following entry is present in the cache '
-                        'but not availible via NSS! %s', map_entry.name)
-                    self.log.debug('missing entry data: %s', map_entry)
+                        "The following entry is present in the cache "
+                        "but not availible via NSS! %s",
+                        map_entry.name,
+                    )
+                    self.log.debug("missing entry data: %s", map_entry)
                     missing_entries += 1
 
             if missing_entries > 0:
-                self.log.warning('Missing %d entries in %s map',
-                                 missing_entries, map_name)
+                self.log.warning(
+                    "Missing %d entries in %s map", missing_entries, map_name
+                )
                 retval += 1
 
         return retval
@@ -506,13 +514,13 @@ class Verify(Command):
                 try:
                     source = source_factory.Create(source_options)
                 except error.SourceUnavailable as e:
-                    self.log.debug('map %s dumps source error %s', map_name, e)
-                    self.log.error('Map %s is unvavailable!', map_name)
+                    self.log.debug("map %s dumps source error %s", map_name, e)
+                    self.log.error("Map %s is unvavailable!", map_name)
                     retval += 1
                     continue
                 retval += source.Verify()
         else:
-            self.log.error('No sources configured for any maps!')
+            self.log.error("No sources configured for any maps!")
             retval += 1
 
         return retval
@@ -543,15 +551,15 @@ class Help(Command):
             help_text = self.Help()
         else:
             help_command = args.pop()
-            print(('Usage: nsscache [global options] %s [options]' %
-                   help_command))
+            print(("Usage: nsscache [global options] %s [options]" % help_command))
             print()
             try:
-                callable_action = getattr(inspect.getmodule(self),
-                                          help_command.capitalize())
+                callable_action = getattr(
+                    inspect.getmodule(self), help_command.capitalize()
+                )
                 help_text = callable_action().Help()
             except AttributeError:
-                print(('command %r is not implemented' % help_command))
+                print(("command %r is not implemented" % help_command))
                 return 1
 
         print(help_text)
@@ -583,30 +591,31 @@ class Repair(Command):
             return e.code
 
         if options.maps:
-            self.log.info('Setting configured maps to %s', options.maps)
+            self.log.info("Setting configured maps to %s", options.maps)
             conf.maps = options.maps
 
         (warnings, errors) = (0, 0)
 
-        self.log.info('Verifying program and system configuration.')
+        self.log.info("Verifying program and system configuration.")
         (config_warnings, config_errors) = config.VerifyConfiguration(conf)
         warnings += config_warnings
         errors += config_errors
 
-        self.log.info('Verifying data sources.')
+        self.log.info("Verifying data sources.")
         errors += Verify().VerifySources(conf)
 
-        self.log.info('verification: %d warnings, %d errors', warnings, errors)
+        self.log.info("verification: %d warnings, %d errors", warnings, errors)
 
         # Exit and report if config or source failed verification, because
         # we cannot reliably build a cache if either of these are faulty.
         if errors > 0:
-            self.log.error('Too many errors in verification tests failed;'
-                           ' repair aborted!')
+            self.log.error(
+                "Too many errors in verification tests failed;" " repair aborted!"
+            )
             return 1
 
         # Rebuild local cache in full, which also verifies each cache.
-        self.log.info('Rebuilding and verifying caches: %s.', conf.maps)
+        self.log.info("Rebuilding and verifying caches: %s.", conf.maps)
         return Update().UpdateMaps(conf=conf, incremental=False)
 
 
@@ -619,24 +628,31 @@ class Status(Command):
 
     def __init__(self):
         super(Status, self).__init__()
-        self.parser.add_option('--epoch',
-                               action='store_true',
-                               help='show timestamps in UNIX epoch time',
-                               dest='epoch',
-                               default=False)
-        self.parser.add_option('--template',
-                               action='store',
-                               help='Set format for output',
-                               metavar='FORMAT',
-                               dest='template',
-                               default='NSS map: %(map)s\n%(key)s: %(value)s')
-        self.parser.add_option('--automount-template',
-                               action='store',
-                               help='Set format for automount output',
-                               metavar='FORMAT',
-                               dest='automount_template',
-                               default=('NSS map: %(map)s\nAutomount map: '
-                                        '%(automount)s\n%(key)s: %(value)s'))
+        self.parser.add_option(
+            "--epoch",
+            action="store_true",
+            help="show timestamps in UNIX epoch time",
+            dest="epoch",
+            default=False,
+        )
+        self.parser.add_option(
+            "--template",
+            action="store",
+            help="Set format for output",
+            metavar="FORMAT",
+            dest="template",
+            default="NSS map: %(map)s\n%(key)s: %(value)s",
+        )
+        self.parser.add_option(
+            "--automount-template",
+            action="store",
+            help="Set format for automount output",
+            metavar="FORMAT",
+            dest="automount_template",
+            default=(
+                "NSS map: %(map)s\nAutomount map: " "%(automount)s\n%(key)s: %(value)s"
+            ),
+        )
 
     def Run(self, conf, args):
         """Run the Status command.
@@ -657,33 +673,31 @@ class Status(Command):
             return e.code
 
         if options.maps:
-            self.log.info('Setting configured maps to %s', options.maps)
+            self.log.info("Setting configured maps to %s", options.maps)
             conf.maps = options.maps
 
         for map_name in conf.maps:
             # Hardcoded to support the two-tier structure of automount maps
             if map_name == config.MAP_AUTOMOUNT:
-                value_list = self.GetAutomountMapMetadata(conf,
-                                                          epoch=options.epoch)
-                self.log.debug('Value list: %r', value_list)
+                value_list = self.GetAutomountMapMetadata(conf, epoch=options.epoch)
+                self.log.debug("Value list: %r", value_list)
                 for value_dict in value_list:
-                    self.log.debug('Value dict: %r', value_dict)
+                    self.log.debug("Value dict: %r", value_dict)
                     output = options.automount_template % value_dict
                     print(output)
             else:
                 for value_dict in self.GetSingleMapMetadata(
-                        map_name, conf, epoch=options.epoch):
-                    self.log.debug('Value dict: %r', value_dict)
+                    map_name, conf, epoch=options.epoch
+                ):
+                    self.log.debug("Value dict: %r", value_dict)
                     output = options.template % value_dict
                     print(output)
 
         return os.EX_OK
 
-    def GetSingleMapMetadata(self,
-                             map_name,
-                             conf,
-                             automount_mountpoint=None,
-                             epoch=False):
+    def GetSingleMapMetadata(
+        self, map_name, conf, automount_mountpoint=None, epoch=False
+    ):
         """Return metadata from map specified.
 
         Args:
@@ -698,20 +712,22 @@ class Status(Command):
         """
         cache_options = conf.options[map_name].cache
 
-        updater = map_updater.MapUpdater(map_name, conf.timestamp_dir,
-                                         cache_options, automount_mountpoint)
+        updater = map_updater.MapUpdater(
+            map_name, conf.timestamp_dir, cache_options, automount_mountpoint
+        )
 
-        modify_dict = {'key': 'last-modify-timestamp', 'map': map_name}
-        update_dict = {'key': 'last-update-timestamp', 'map': map_name}
+        modify_dict = {"key": "last-modify-timestamp", "map": map_name}
+        update_dict = {"key": "last-update-timestamp", "map": map_name}
         if map_name == config.MAP_AUTOMOUNT:
             # have to find out *which* automount map from a cache object!
             cache = cache_factory.Create(
                 cache_options,
                 config.MAP_AUTOMOUNT,
-                automount_mountpoint=automount_mountpoint)
+                automount_mountpoint=automount_mountpoint,
+            )
             automount = cache.GetMapLocation()
-            modify_dict['automount'] = automount
-            update_dict['automount'] = automount
+            modify_dict["automount"] = automount
+            update_dict["automount"] = automount
 
         last_modify_timestamp = updater.GetModifyTimestamp() or 0
         last_update_timestamp = updater.GetUpdateTimestamp() or 0
@@ -721,17 +737,19 @@ class Status(Command):
             # the only place such a conversion is appropriate.
             if last_modify_timestamp:
                 last_modify_timestamp = time.asctime(
-                    time.localtime(last_modify_timestamp))
+                    time.localtime(last_modify_timestamp)
+                )
             else:
-                last_modify_timestamp = 'Unknown'
+                last_modify_timestamp = "Unknown"
             if last_update_timestamp:
                 last_update_timestamp = time.asctime(
-                    time.localtime(last_update_timestamp))
+                    time.localtime(last_update_timestamp)
+                )
             else:
-                last_update_timestamp = 'Unknown'
+                last_update_timestamp = "Unknown"
 
-        modify_dict['value'] = last_modify_timestamp
-        update_dict['value'] = last_update_timestamp
+        modify_dict["value"] = last_modify_timestamp
+        update_dict["value"] = last_update_timestamp
 
         return [modify_dict, update_dict]
 
@@ -755,21 +773,21 @@ class Status(Command):
 
         # get the value_dict for the master map, note that automount_mountpoint=None
         # defaults to the master map!
-        values = self.GetSingleMapMetadata(map_name,
-                                           conf,
-                                           automount_mountpoint=None,
-                                           epoch=epoch)
+        values = self.GetSingleMapMetadata(
+            map_name, conf, automount_mountpoint=None, epoch=epoch
+        )
         value_list.extend(values)
 
         # now get the contents of the master map, and get the status for each map
         # we find
-        cache = cache_factory.Create(cache_options,
-                                     config.MAP_AUTOMOUNT,
-                                     automount_mountpoint=None)
+        cache = cache_factory.Create(
+            cache_options, config.MAP_AUTOMOUNT, automount_mountpoint=None
+        )
         master_map = cache.GetMap()
 
         for map_entry in master_map:
             values = self.GetSingleMapMetadata(
-                map_name, conf, automount_mountpoint=map_entry.key, epoch=epoch)
+                map_name, conf, automount_mountpoint=map_entry.key, epoch=epoch
+            )
             value_list.extend(values)
         return value_list
